@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     houchengqiu <houchengqiu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef GRANDSEARCHLISTDELEGATE_H
 #define GRANDSEARCHLISTDELEGATE_H
@@ -26,6 +11,8 @@
 #include <QScopedPointer>
 #include <DStyledItemDelegate>
 
+namespace GrandSearch {
+
 class GrandSearchListDelegate : public Dtk::Widget::DStyledItemDelegate
 {
     Q_OBJECT
@@ -56,4 +43,6 @@ private:
     QMap<int, QString> calcTailShowDataByOptimalWidth(QStringList &strings, const int &tailCount, int averageWidth, const QFontMetrics &fontMetrics) const;
 };
 
+}
+
 #endif // GRANDSEARCHLISTDELEGATE_H
